@@ -17,7 +17,14 @@ use Log::Handler;
 
 # ---------------
 
-exit 0 if (! $ENV{DBI_DSN});
+if (! $ENV{DBI_DSN})
+{
+	print "DBI_DSN etc not set\n";
+
+	# Return 0 for OK and 1 for error.
+
+	exit 1;
+}
 
 my($logger) = Log::Handler -> new;
 
@@ -55,3 +62,7 @@ my($format)      = shift || 'svg';
 my($output_file) = shift || File::Spec -> catfile('html', "dbi.schema.$format");
 
 $graph -> run(format => $format, output_file => $output_file);
+
+# Return 0 for OK and 1 for error.
+
+exit 0;
